// Toggle classes on Dropdowns/Modals/Menus/Toasts
function toggleClasses() {
   var targetSelectors = $(this).data('target').split(','); // Split multiple targets by comma
   var $targets = $(); // Initialize an empty jQuery object

   // Iterate over each target selector
   targetSelectors.forEach(function(targetSelector) {
      var $target;

      targetSelector = targetSelector.trim(); // Trim whitespace from selector

      if (targetSelector === "self") {
         $target = $(this);
      } else if (targetSelector === "parent") {
         $target = $(this).parent();
      } else {
         $target = $(this).siblings(targetSelector);
         if ($target.length === 0) {
            // If no sibling found, use the global selector
            $target = $(targetSelector);
         }
      }

      // Add found targets to the main jQuery object
      $targets = $targets.add($target);
   }, this); // Ensure 'this' refers to the clicked element

   if ($targets.length > 0) {
      $targets.toggleClass('active');
   }

   // Check for data-overlay attribute
   if ($(this).data('overlay') === true) {
      $('.overlay').toggleClass('active');
   }

   // Check for data-fixed attribute
   if ($(this).data('fixed') === true) {
      $('body').toggleClass('fixed');
   }

   // Check for data-dropdown attribute
   if ($(this).data('dropdown') === true && $(window).width() >= 640) {
      $('body').removeClass('fixed');
      $('.overlay').removeClass('active');
   }

   // Check for data-modal attribute
   if ($(this).data('modal') === true) {
      if (!$('.overlay').hasClass('active')) {
         $('.overlay').addClass('active');
      }
      if (!$('body').hasClass('fixed')) {
         $('body').addClass('fixed');
      }
   }

   // Handle toast-related data attributes
   var toastTarget = $(this).data('toast-target');
   if (toastTarget) {
      var $toast = $(toastTarget);
      $toast.toggleClass('active');

      // Always apply the toast class
      var toastClass = $(this).data('toast-class');
      if (toastClass) {
         $toast.addClass(toastClass);
      }

      // Update toast title and message based on new data attributes if .active is present
      if ($toast.hasClass('active')) {
         var newTitle = $(this).data('active-toast-title');
         var newMessage = $(this).data('active-toast-message');

         if (newTitle !== undefined) {
            $toast.find('h3').html(newTitle);
         }

         if (newMessage !== undefined) {
            $toast.find('p').html(newMessage);
         }
      } else {
         // Handle default toast title and message if needed
         if ($(this).data('toast-title')) {
            $toast.find('h3').html($(this).data('toast-title'));
         }

         if ($(this).data('toast-message')) {
            $toast.find('p').html($(this).data('toast-message'));
         }
      }

      // Set a timeout to hide the toast after 5 seconds
      setTimeout(function () {
         $toast.removeClass('active');
      }, 5000); // 5000 milliseconds = 5 seconds
   }
}

// Bind the function to your event listener, e.g., click
$(document).on('click', '.toggle-button', toggleClasses);









$(document).ready(function () {
   // Function to close all modals and overlay
   function closeModals() {
      $('.dropdown-container.active, .modal.active').removeClass('active');
      $('.overlay.active').removeClass('active');
      $('body').removeClass('fixed');
   }

   // Click event to close modal if clicked outside
   $(document).mouseup(function (e) {
      var container = $('.dropdown-container.active, .modal.active');
      if (!container.is(e.target) && container.has(e.target).length === 0) {
         closeModals();
      }
   });

   // Keydown event to close modal on Escape key press
   $(document).keydown(function (e) {
      if (e.key === "Escape") {
         closeModals();
      }
   });
});


$(document).ready(function () {
   // Function to toggle the disabled attribute and title attribute
   function toggleCreateButton() {
      var $createButton = $('.create-new-list-button');
      if ($('#newListTitle').val().trim() === '') {
         $createButton.attr('disabled', 'disabled');
         $createButton.attr('title', 'Please enter a list name'); // Add title attribute
      } else {
         $createButton.removeAttr('disabled');
         $createButton.removeAttr('title'); // Remove title attribute
      }
   }

   // Initial check when the page loads
   toggleCreateButton();

   // Event listener for input changes
   $('#newListTitle').on('input', function () {
      toggleCreateButton();
   });
});

$(document).ready(function () {
   $('.create-new-list-button').click(function () {
      var newListTitle = $('#newListTitle').val().trim();

      if (newListTitle !== '') {
         // Clear input field
         $('#newListTitle').val('');

         // Remove .active class from .dropdown-new-list-container
         $('.dropdown-new-list-container').removeClass('active');

         // Generate a unique ID for the new checkbox
         var newCheckboxId = 'checkbox' + ($('.checkbox-container').length + 1);

         // Create new checkbox container HTML
         var newCheckboxHTML = '<div class="checkbox-container">' +
            '<input type="checkbox" id="' + newCheckboxId + '" checked>' +
            '<label for="' + newCheckboxId + '">' +
            '<span class="checkbox-label">' + newListTitle + '</span>' +
            '<span class="custom-checkbox">' +
            '<i class="fa-solid fa-check"></i>' +
            '</span>' +
            '</label>' +
            '</div>';

         // Insert new checkbox container above the first one
         $('.checkbox-container').first().before(newCheckboxHTML);
      }
   });
});


// Function to adjust the dimensions of the image containers
function adjustImageContainers() {
   if ($(window).width() <= 1279) {
       $('.img-container').each(function() {
           var $imgContainer = $(this);
           var width = $imgContainer.width();
           var height = width * 0.5625;

           $imgContainer.css('height', height);

           if ($imgContainer.parent('.author').length) {
               $imgContainer.css('width', height);
           }
       });
   } else {
       // Reset the styles if the width is above 1279px
       $('.img-container').css({
           'height': '',
           'width': ''
       });
   }
}

// Debounce function to limit the rate at which a function can fire
function debounce(func, wait) {
   var timeout;
   return function() {
       clearTimeout(timeout);
       timeout = setTimeout(func, wait);
   };
}

// Ensure Card Image is 16:9 when document is ready
$(document).ready(function() {
   adjustImageContainers();

   // Adjust dimensions on window resize with debouncing
   $(window).resize(debounce(adjustImageContainers, 100));
});


//Get year
$(document).ready(function () {
   var currentYear = new Date().getFullYear();
   $('#current-year').text(currentYear);
});